Story
-spec deleteStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), story_id := integer()}) -> Result :: result(true).
Equivalent to deleteStory(Pool, Req, false).
-spec deleteStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), story_id := integer()}, Async :: boolean()) -> Result :: result(true).
Equivalent to deleteStory(Pool, Req, Async, 5000).
-spec deleteStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), story_id := integer()}, Async :: boolean(), Timeout :: timeout()) -> Result :: result(true).
Deletes a story previously posted by the bot on behalf of a managed business account.
Requires the can_manage_stories business bot right.
Returns True on success.
Parameters
business_connection_id- Unique identifier of the business connectionstory_id- Unique identifier of the story to delete
-spec editStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), story_id := integer(), content := 'InputStoryContent'(), caption => binary(), parse_mode => binary(), caption_entities => ['MessageEntity'(), ...], areas => ['StoryArea'(), ...], file_attach_name() => multipart_file()}) -> Result :: result('Story'()).
Equivalent to editStory(Pool, Req, false).
-spec editStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), story_id := integer(), content := 'InputStoryContent'(), caption => binary(), parse_mode => binary(), caption_entities => ['MessageEntity'(), ...], areas => ['StoryArea'(), ...], file_attach_name() => multipart_file()}, Async :: boolean()) -> Result :: result('Story'()).
Equivalent to editStory(Pool, Req, Async, 5000).
-spec editStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), story_id := integer(), content := 'InputStoryContent'(), caption => binary(), parse_mode => binary(), caption_entities => ['MessageEntity'(), ...], areas => ['StoryArea'(), ...], file_attach_name() => multipart_file()}, Async :: boolean(), Timeout :: timeout()) -> Result :: result('Story'()).
Edits a story previously posted by the bot on behalf of a managed business account.
Requires the can_manage_stories business bot right.
Returns Story on success.
Parameters
business_connection_id- Unique identifier of the business connectionstory_id- Unique identifier of the story to editcontent- Content of the storycaption- Caption of the story, 0-2048 characters after entities parsingparse_mode- Mode for parsing entities in the story caption. See formatting options for more details.caption_entities- A JSON-serialized list of special entities that appear in the caption, which can be specified instead of parse_modeareas- A JSON-serialized list of clickable areas to be shown on the story
-spec postStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), content := 'InputStoryContent'(), active_period := integer(), caption => binary(), parse_mode => binary(), caption_entities => ['MessageEntity'(), ...], areas => ['StoryArea'(), ...], post_to_chat_page => boolean(), protect_content => boolean(), file_attach_name() => multipart_file()}) -> Result :: result('Story'()).
Equivalent to postStory(Pool, Req, false).
-spec postStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), content := 'InputStoryContent'(), active_period := integer(), caption => binary(), parse_mode => binary(), caption_entities => ['MessageEntity'(), ...], areas => ['StoryArea'(), ...], post_to_chat_page => boolean(), protect_content => boolean(), file_attach_name() => multipart_file()}, Async :: boolean()) -> Result :: result('Story'()).
Equivalent to postStory(Pool, Req, Async, 5000).
-spec postStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), content := 'InputStoryContent'(), active_period := integer(), caption => binary(), parse_mode => binary(), caption_entities => ['MessageEntity'(), ...], areas => ['StoryArea'(), ...], post_to_chat_page => boolean(), protect_content => boolean(), file_attach_name() => multipart_file()}, Async :: boolean(), Timeout :: timeout()) -> Result :: result('Story'()).
Posts a story on behalf of a managed business account.
Requires the can_manage_stories business bot right.
Returns Story on success.
Parameters
business_connection_id- Unique identifier of the business connectioncontent- Content of the storyactive_period- Period after which the story is moved to the archive, in seconds; must be one of 6 3600, 12 3600, 86400, or 2 * 86400caption- Caption of the story, 0-2048 characters after entities parsingparse_mode- Mode for parsing entities in the story caption. See formatting options for more details.caption_entities- A JSON-serialized list of special entities that appear in the caption, which can be specified instead of parse_modeareas- A JSON-serialized list of clickable areas to be shown on the storypost_to_chat_page- Pass True to keep the story accessible after it expiresprotect_content- Pass True if the content of the story must be protected from forwarding and screenshotting
-spec repostStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), from_chat_id := integer(), from_story_id := integer(), active_period := integer(), post_to_chat_page => boolean(), protect_content => boolean()}) -> Result :: result('Story'()).
Equivalent to repostStory(Pool, Req, false).
-spec repostStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), from_chat_id := integer(), from_story_id := integer(), active_period := integer(), post_to_chat_page => boolean(), protect_content => boolean()}, Async :: boolean()) -> Result :: result('Story'()).
Equivalent to repostStory(Pool, Req, Async, 5000).
-spec repostStory(Pool :: pool_name(), Req :: #{business_connection_id := binary(), from_chat_id := integer(), from_story_id := integer(), active_period := integer(), post_to_chat_page => boolean(), protect_content => boolean()}, Async :: boolean(), Timeout :: timeout()) -> Result :: result('Story'()).
Reposts a story on behalf of a business account from another business account.
Both business accounts must be managed by the same bot, and the story on the source account must have been posted (or reposted) by the bot.
Requires the can_manage_stories business bot right for both business accounts.
Returns Story on success.
Parameters
business_connection_id- Unique identifier of the business connectionfrom_chat_id- Unique identifier of the chat which posted the story that should be repostedfrom_story_id- Unique identifier of the story that should be repostedactive_period- Period after which the story is moved to the archive, in seconds; must be one of 6 3600, 12 3600, 86400, or 2 * 86400post_to_chat_page- Pass True to keep the story accessible after it expiresprotect_content- Pass True if the content of the story must be protected from forwarding and screenshotting